@@ -5,12 +5,12 @@ An example that demonstrates how `patch_stdout` works.
 This makes sure that output from other threads doesn't disturb the rendering of
 the prompt, but instead is printed nicely above the prompt.
 """
-from __future__ import unicode_literals
+
+import threading
+import time
 
 from prompt_toolkit import prompt
 from prompt_toolkit.patch_stdout import patch_stdout
-import threading
-import time
 
 
 def main():
@@ -21,8 +21,9 @@ def main():
         i = 0
         while running:
             i += 1
-            print('i=%i' % i)
+            print("i=%i" % i)
             time.sleep(1)
+
     t = threading.Thread(target=thread)
     t.daemon = True
     t.start()
@@ -30,12 +31,12 @@ def main():
     # Now read the input. The print statements of the other thread
     # should not disturb anything.
     with patch_stdout():
-        result = prompt('Say something: ')
-    print('You said: %s' % result)
+        result = prompt("Say something: ")
+    print(f"You said: {result}")
 
     # Stop thread.
     running = False
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
